@@ -41,7 +41,7 @@ fi
 
 # Normalize to the basename of the manpage
 manpage=$(basename $1)
-mandir="man"$(echo $manpage | sed -e "s/.*\.\([0-9]\).\?$/\1/")
+mandir="man"$(echo $manpage | sed -e 's/[a-z]*$//' | sed -e "s/.*\.\([0-9]\).\?$/\1/")
 pofile=$mandir/$manpage.po
 potfile=../../templates/$mandir/$manpage.pot
 
